# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct

class TestDbKnowledgeProduct(unittest.TestCase):
    """DbKnowledgeProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbKnowledgeProduct:
        """Test DbKnowledgeProduct
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbKnowledgeProduct`
        """
        model = DbKnowledgeProduct()
        if include_optional:
            return DbKnowledgeProduct(
                client_id = '',
                entity_id = '',
                handle = '',
                overview = '',
                product_hash = '',
                product_id = neurograph.v1.models.pgtype/int8.pgtype.Int8(
                    int64 = 56, 
                    valid = True, ),
                summary = '',
                title = '',
                type = ''
            )
        else:
            return DbKnowledgeProduct(
        )
        """

    def testDbKnowledgeProduct(self):
        """Test DbKnowledgeProduct"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
