# flake8: noqa

if __import__("typing").TYPE_CHECKING:
    # import apis into api package
    from neurograph.v1.api.authentication_api import AuthenticationApi
    from neurograph.v1.api.client_api import ClientApi
    from neurograph.v1.api.client_metadata_api import ClientMetadataApi
    from neurograph.v1.api.dagster_api import DagsterApi
    from neurograph.v1.api.knowledge_api import KnowledgeApi
    from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi
    from neurograph.v1.api.lookup_api import LookupApi
    from neurograph.v1.api.organization_api import OrganizationApi
    from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi
    from neurograph.v1.api.persona_api import PersonaApi
    from neurograph.v1.api.system_api import SystemApi
    from neurograph.v1.api.workbench_api import WorkbenchApi
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import apis into api package
from neurograph.v1.api.authentication_api import AuthenticationApi
from neurograph.v1.api.client_api import ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi
from neurograph.v1.api.organization_api import OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi
from neurograph.v1.api.system_api import SystemApi
from neurograph.v1.api.workbench_api import WorkbenchApi

""",
            name=__name__,
            doc=__doc__,
        )
    )
